@@ -6,7 +6,7 @@
 # License           : BSD License
 # -----------------------------------------------------------------------------
 # Creation date     : 14-Jul-2013
-# Last modification : 19-Jan-2015
+# Last modification : 29-Jan-2015
 # -----------------------------------------------------------------------------
 
 import re, os, sys, argparse, json
@@ -17,7 +17,7 @@ try:
 except ImportError:
 	reporter = None
 
-VERSION = "0.1.0"
+VERSION = "0.1.1"
 LICENSE = "http://ffctn.com/doc/licenses/bsd"
 
 __doc__ = """
@@ -112,6 +112,7 @@ def grammar(g=None):
 	g.token   ("COLOR_NAME",       "[a-z][a-z0-9\-]*")
 	g.token   ("COLOR_HEX",        "\#([A-Fa-f0-9][A-Fa-f0-9]?[A-Fa-f0-9]?[A-Fa-f0-9]?[A-Fa-f0-9]?[A-Fa-f0-9]?([A-Fa-f0-9][A-Fa-f0-9])?)")
 	g.token   ("COLOR_RGB",        "rgba?\((\s*\d+\s*,\s*\d+\s*,\s*\d+\s*(,\s*\d+(\.\d+)?\s*)?)\)")
+	g.token   ("URL",              "url\((\"[^\"]*\"|\'[^\']*\'|[^\)]*)\)")
 	g.token   ("CSS_PROPERTY",    "[\-a-z][\-a-z0-9]*")
 	g.token   ("SPECIAL_NAME",     "@[A-Za-z][A-Za-z0-9\_\-]*")
 	g.token   ("SPECIAL_FILTER",   "\[[^\]]+\]")
@@ -140,7 +141,7 @@ def grammar(g=None):
 	g.group     ("Suffixes")
 	g.rule      ("Number",           s.NUMBER._as("value"), s.UNIT.optional()._as("unit"))
 	g.group     ("String",           s.STRING_SQ, s.STRING_DQ, s.STRING_UQ)
-	g.group     ("Value",            s.Number, s.COLOR_HEX, s.COLOR_RGB, s.REFERENCE, s.String)
+	g.group     ("Value",            s.Number, s.COLOR_HEX, s.COLOR_RGB, s.URL, s.REFERENCE, s.String)
 	g.rule      ("Parameters",       s.VARIABLE_NAME, g.arule(s.COMMA, s.VARIABLE_NAME).zeroOrMore())
 	g.rule      ("Arguments",        s.Value, g.arule(s.COMMA, s.Value).zeroOrMore())
 	g.rule      ("Expression")
@@ -425,6 +426,9 @@ class Processor(AbstractProcessor):
 	# GRAMMAR RULES
 	# ==========================================================================
 
+	def onURL(self, match ):
+		return (match.group(0), "S")
+
 	def onCOLOR_HEX(self, match ):
 		c = (match.group(1))
 		while len(c) < 6: c += "0"
@@ -880,7 +884,7 @@ def run(args):
 	if not args.files:
 		sys.stderr.write(USAGE + "\n")
 	output = sys.stdout
-	# if args.verbose: getGrammar().setVerbose()
+	if args.verbose: getGrammar().setVerbose()
 	if args.output: output = open(args.output, "w")
 	for a in args.files:
 		if reporter: reporter.info("Processing: {0}".format(a))
